import helper from './helper.js';

export function promiseRequest(url, data, method = "GET", showLoading = true) {
	if (showLoading) {
		uni.showLoading({
			mask: true
		});
	}
	return new Promise((resolve, reject) => {
		let header = {
			appname: helper.appname,
			platform: uni.getSystemInfoSync().platform
		};
		let token = uni.getStorageSync('token');

		if (token !== '') {
			header['Authori-zation'] = "Bearer " + token;
		}
		data = JSON.stringify(data);
		uni.request({
			url: url,
			header: header,
			data: data,
			method: method,
			responseType: 'json',
			success: function(res) {
				if (res.data.status == 410000 || res.data.status == 410001) {
					removeConfig();
					uni.showToast({
						title: res.data.msg ? res.data.msg : '请重新登录',
						icon: 'none',
						duration: 2000,
						mask: true,
						success() {
							setTimeout(function() {
								uni.navigateTo({
									url: helper.pageDirectory.login
								})
							}, 1000)
						}
					})
				} else if (res.statusCode === 401) {
					removeConfig();
					uni.showToast({
						title: res.data,
						icon: 'none',
						duration: 2000,
						mask: true,
						success() {
							setTimeout(function() {
								uni.navigateTo({
									url: helper.pageDirectory.login
								})
							}, 1000)
						}
					})
				} else {
					resolve(res.data);
				}

			},
			fail: function(err) {
				console.log(err)
				uni.showToast({
					title: '网络错误,请稍候重试',
					icon: 'none',
					mask: true
				});
			}
		})
	})
}

export function removeConfig() {
	uni.removeStorageSync('expires_time');
	uni.removeStorageSync('token');
}
