import helper from './helper.js'
import {
	promiseRequest
} from './http.js'

function payWithAli(orderInfo, that) {
	uni.requestPayment({
		orderInfo: orderInfo,
		provider: 'alipay',
		success: res => {
			uni.hideLoading();
			var rawdataStr = res.rawdata;
			var rawdata = JSON.parse(rawdataStr);
			var result = rawdata.result.split('};extendInfo=')[0];
			result = JSON.parse(result);
			var response = result.alipay_trade_app_pay_response;
			if (typeof response === 'string') {
				response = JSON.parse(response);
			}
			if (response.code === '10000') {
				waitingReceipt(response.out_trade_no, 1, that);
			} else {
				uni.showToast({
					title: res.sub_msg,
					icon: 'none',
					mask: true
				});
			}
		},
		fail: err => {
			console.log(err);
			uni.showToast({
				title: "支付失败",
				icon: 'none',
				mask: true
			});
		}
	});
}

function payWithWx(orderInfo, that) {
	var orderInfoStr = typeof orderInfo === 'object' ? JSON.stringify(orderInfo) : orderInfo;
	uni.requestPayment({
		provider: 'wxpay',
		orderInfo: orderInfoStr,
		success: res => {
			let rawdata = JSON.parse(res.rawdata);
			waitingReceipt(rawdata._wxapi_payresp_prepayid, 2, that);
		},
		fail: err => {
			console.log(err);
			uni.showToast({
				title: "支付失败",
				icon: 'none',
				mask: true
			});
		}
	});
}

function waitingReceipt(out_order_no, way = 1, that) {
	uni.showLoading({
		title: '支付中，请稍候...',
		mask: true
	});
	var time = 0;
	let query = 'prepayid=';
	if (way === 1) {
		query = 'order_no=';
	}

	query = query + out_order_no;
	setPostOrderTimer(query, that);
}

function setPostOrderTimer(query, that, counter = 0) {
	setTimeout(function() {
		promiseRequest(`${helper.commonUrl}/api/v2/creditOrder/orderNo?${query}`, '', 'GET', false)
			.then(res => {
				if (res.status === 200 && res.data.status === 2) {
					let order = res.data;
					uni.showToast({
						title: '支付成功，正在跳转...',
						icon: 'loading',
						mask: true,
						success: () => {
							let url = "";
							//获取产品 类型
							let typeName = "";
							for (var index in helper.tradeNames) {
								if (helper.tradeNames[index] == order.order_items[0].tradeName) {
									typeName = index;
								}
							}
							//支付成功跳转
							if (typeName == "jingque") {
								url = `${helper.pageDirectory.resultEnterpriseDetail}?orderNo=${order.order_no}`
							} else if (typeName == "jiben") {
								url = `${helper.pageDirectory.resultEnterpriseSimple}?orderNo=${order.order_no}`
							} else if (typeName == "gongshang") {
								url = `${helper.pageDirectory.resultIndustry}?orderNo=${order.order_no}`
							} else if (typeName == "yichang") {
								url = `${helper.pageDirectory.resultCompanyException}?orderNo=${order.order_no}`
							} else if (typeName == "geren") {
								that.checkTwoElement();
								return false;
								// url = `${helper.pageDirectory.ordersReport}?orderNo=${order.order_no}`
							} else if (typeName.indexOf("_shiti") != -1) {
								url = `${helper.pageDirectory.ordersStdetail}?orderNo=${order.order_no}`
							} else {
								uni.showToast({
									title: typeName+' not found',
									mask: true,
									icon: 'none'
								});
								return false;
							}
							uni.redirectTo({
								url: url
							})
						}
					});
				} else {
					if (counter >= 10) {
						uni.hideLoading();
						uni.showToast({
							title: '支付失败，请联系客服',
							icon: 'none',
							mask: true
						});
					} else {
						setPostOrderTimer(query, that, ++counter);
					}
				}
			})
			.catch(err => {
				uni.hideLoading();
				console.log(err);
				uni.showToast({
					title: '支付失败，请联系客服',
					mask: true
				});
			});
	}, 1000);
}
function payWithApple(orderInfo, trade_id, that) {
	var data = {
		productid: trade_id,
		username: orderInfo.buyer
	};
	uni.requestPayment({
		provider: 'appleiap',
		orderInfo: data,
		success: (res) => {
			let postData = {
				receipt: res.transactionReceipt,
				transaction_id: res.transactionIdentifier,
				order_no: orderInfo.order_no
			};
			postIapReceipt(postData, that);
		},
		fail: (err) => {
			console.log(err);
			uni.hideLoading();
			uni.showToast({
				title: '已取消支付',
				icon: 'none',
				mask: true
			});
		}
	});
}
function postIapReceipt(postData, that) {
	promiseRequest(`${helper.commonUrl}/api/applepay`, postData, 'POST')
		.then(res => {
			if (res.code == 200) {
				waitingReceipt(postData.order_no, 1, that);
			} else {
				uni.hideLoading();
				uni.showToast({
					title: res.msg || "支付出错",
					icon: 'none',
					mask: true
				});
			}
		})
		.catch(err => {
			console.log(err);
			uni.hideLoading();
		});
}
export {
	payWithAli,
	payWithWx,
	payWithApple
}
